@@ -54,6 +54,7 @@ public:
     };
 
     bool matches(const GpgME::Key &key, MatchContexts ctx) const override;
+    bool matches(const GpgME::UserID &userID, MatchContexts ctx) const override;
 
     unsigned int specificity() const override;
     void setSpecificity(unsigned int value);
@@ -75,6 +76,8 @@ public:
     void setIcon(const QString &value);
     QFont font() const;
     void setFont(const QFont &value);
+    QString description() const override;
+    void setDescription(const QString &description);
 
     TriState revoked() const;
     TriState expired() const;
@@ -85,6 +88,10 @@ public:
     TriState canSign() const;
     TriState canCertify() const;
     TriState canAuthenticate() const;
+    TriState hasEncrypt() const;
+    TriState hasSign() const;
+    TriState hasCertify() const;
+    TriState hasAuthenticate() const;
     TriState qualified() const;
     TriState cardKey() const;
     TriState hasSecret() const;
@@ -112,6 +119,10 @@ public:
     void setCanSign(const TriState);
     void setCanCertify(const TriState);
     void setCanAuthenticate(const TriState);
+    void setHasEncrypt(const TriState);
+    void setHasSign(const TriState);
+    void setHasCertify(const TriState);
+    void setHasAuthenticate(const TriState);
     void setQualified(const TriState);
     void setCardKey(const TriState);
     void setHasSecret(const TriState);
